unit Mailit;
//==========================================================================
// Copyright  1999 by Dirk Siepe,
//   Sankt Augustin, Germany, eMail : uzs74h@uni-bonn.de

//Standard disclaimer, standard PostCardWare.
//No warranty is given by the author, expressed or implied.
//This component works like TLabel and has some additional properties:
//
//  - MailTo: Insert recipient
//  - MailSubject: Insert Subject (advice from Siegfried Wessler)
//  - MailHint : Insert Hint Text
//  - MailCC  : Insert CC Mail
//  - MailBCC : Insert BCC Mail
//  - ColorEnter : Select the color to be used, when the mouse enters the label
//  - ColorLeave : Select the color to be used, when the mouse leaves the label
//  - MailCursor(true/false) : You can choose a special Cursor...
//
//--------------------------------------------------------------------------
// Vers.  Date      Remarks
// 1.2.0  02.04.99  new release
//--------------------------------------------------------------------------
//Any suggestions, bugs, informations or anything I haven't thought of,
//mail to : uzs74h@uni-bonn.de
//==========================================================================
//History
//--------------------------------------------------------------------------
//1.0.1 :		Initial Release
//1.0.2 : 	fixed error with wrong version, sorry about that...
//
//==========================================================================
// MOST IMPORTANT :)
//==========================================================================
//  This is NOT Freeware: It's PostCardWare. When you use
//  this component or think it's useful, send me a post-card
//  to: Dirk Siepe, Haberstr. 36, D - 53757 Sankt Augustin, Germany
//==========================================================================
//  And of course, I am very interested in any application
//  that uses this component (or any other application you wrote).
//  If so, mail me (not the program, just an URL or similar) !
//  (see mail address above)
//==========================================================================

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ShellApi;

type
  TMailit = class(TCustomLabel)
  private
    { Private-Deklarationen }
    property Hint;
    property Caption;
  protected
    { Protected-Deklarationen }
    FMailTo : String;
		FMailSubject: String;
		FCursorStyle : boolean;
		FColorLeave : TColor;
		FColorEnter : TColor;
    FMailHint: String;
    FMailCC: String;
    FmailBCC: String;
    FMailBody : String;
		procedure SetMailTo(aVal : String);
		function GetMailTo : String;
		procedure SetMailSubject(aVal: String);						//we
		function GetMailSubject: String;									//we
 		procedure SetMailCC(aVal: String);
		function GetMailCC: String;
    procedure SetMailBCC(aVal: String);
		function GetMailBCC: String;
    procedure SetMailHint(aVal : String);
    function GetMailHint : String;
		procedure SetCursorStyle(aVal : boolean);
		procedure SetColorLeave(aVal : TColor);
		procedure Click; override;
	public
		{ Public-Deklarationen }
		constructor Create(AOwner: TComponent); override;
		procedure CMMouseEnter(var Msg: TMessage); message CM_MOUSEENTER;
		procedure CMMouseLeave(var Msg: TMessage); message CM_MOUSELEAVE;
	published
		{ Published-Deklarationen }
		property MailTo : String read GetMailTo write SetMailTo;
		property MailSubject: String read GetMailSubject write SetMailSubject;		//we
    property MailCC: String read GetMailCC write setMailCC;
    property MailBCC: String read GetMailBCC write SetMailBCC;
    property MailCursor : boolean read FCursorStyle write SetCursorStyle default false;
    property ColorLeave : TColor read FColorLeave write SetColorLeave;
    property ColorEnter : TColor read FColorEnter write FColorEnter;
    property MailHint : String read GetMailHint write SetMailHint;
    property AutoSize;
    property Enabled;
    property Font;
    property ParentColor;
    property ParentFont;
    property ParentShowHint;
    property ShowHint;
    property Transparent;
    property Visible;
  end;

procedure Register;

implementation

{$R MCursor.res}

Const
	crMailPtn = 1;

var
  mcr : Tcursor;

procedure Register;
begin
  RegisterComponents('Tools', [TMailIt]);
end;

//==========================================================================
constructor TMailIt.Create(aOwner:TComponent);
//==========================================================================
begin
  inherited Create(aOwner);
  Font.Name := 'Arial';
  Font.Color := clblack;
  mcr :=LoadCursor(hInstance,'CRHANDPTN');
end;

//==========================================================================
procedure TMailIt.SetMailTo(aVal:String);
//==========================================================================
begin
  caption := aVal;
  FMailTo := aval;
end;

//==========================================================================
function TMailIt.GetMailTo : String;
//==========================================================================
begin
  if FMailTo='' then
    result := name
	else result := FMailTo;
end;

//==========================================================================
procedure TMailIt.SetMailHint(aVal : String);
//==========================================================================
begin
  Hint:= aVal;
  FMailHint:= aVal;
end;

//==========================================================================
function TMailIt.GetMailHint : String;
//==========================================================================
begin
  ShowHint:=false;
  if FMailHint='' then
    result:=''
  else begin
    result:= FMailHint;
    ShowHint:=true;
  end;
end;

//==========================================================================
procedure TMailIt.SetMailSubject(aVal:String);					//we
//==========================================================================
begin
	FMailSubject := aval;																	//we
end;

//==========================================================================
function TMailIt.GetMailSubject : String;								//we
//==========================================================================
begin
	if FMailSubject='' then																//we
		result :=''																			//we
	else result := FMailSubject;													//we
end;

//==========================================================================
procedure TMailIt.SetMailCC(aVal:String);
//==========================================================================
begin
	FMailCC := aval;
end;

//==========================================================================
function TMailIt.GetMailCC : String;
//==========================================================================
begin
	if FMailCC='' then
		result :=''
	else result := FMailCC;
end;

//==========================================================================
procedure TMailIt.SetMailBCC(aVal:String);
//==========================================================================
begin
	FMailBCC := aval;
end;

//==========================================================================
function TMailIt.GetMailBCC : String;
//==========================================================================
begin
	if FMailBCC='' then
		result :=''
	else result := FMailBCC;
end;

//==========================================================================
procedure TMailIt.SetCursorStyle(aVal:boolean);
//==========================================================================
begin
  if aVal = true then
  begin
    screen.Cursors[crMailPtn] := mcr;
    cursor := crMailPtn;
  end
  else
    cursor := crDefault;
  FCursorStyle := aVal;
end;

//==========================================================================
procedure TMailIt.Click;
//==========================================================================
var
  x : String;
begin
  x:= 'mailto:'+FMailTo+'?Subject='+FMailSubject+'&cc='+FMailCC+'&bcc='+FMailBCC;
	ShellExecute(0, nil, PChar(x), nil, nil, SW_SHOWDEFAULT);
	inherited click;
end;


//==========================================================================
procedure TMailIt.CMMouseEnter(var Msg: TMessage);
//==========================================================================
begin
	font.color := FColorEnter;
end;

//==========================================================================
procedure TMailIt.CMMouseLeave(var Msg: TMessage);
//==========================================================================
begin
  font.color := FColorLeave;
end;

//==========================================================================
procedure TMailIt.SetColorLeave(aVal : TColor);
//==========================================================================
begin
  FColorLeave := aVal;
  font.color := aVal;
end;

end.
